summaryrefslogtreecommitdiff
path: root/gtk2_ardour
diff options
context:
space:
mode:
authorLen Ovens <len@ovenwerks.net>2018-11-12 22:29:27 -0800
committerLen Ovens <len@ovenwerks.net>2018-11-12 22:30:32 -0800
commit9b2612f68615d1b3f80fce732e4a13f5e50ee87d (patch)
tree9a34b4e9d4b4a9f6c3b8d8f212c707e2fbd340a2 /gtk2_ardour
parentf27ca29d6c7e294a71c46d2e3390331aa72ad1d0 (diff)
Make foldback bus match foldback sends namewise
to avoid confusion with listener sends or monitor bus
Diffstat (limited to 'gtk2_ardour')
-rw-r--r--gtk2_ardour/add_route_dialog.cc22
-rw-r--r--gtk2_ardour/add_route_dialog.h2
-rw-r--r--gtk2_ardour/ardour_ui.cc10
-rw-r--r--gtk2_ardour/ardour_ui.h2
-rw-r--r--gtk2_ardour/processor_box.cc18
5 files changed, 27 insertions, 27 deletions
diff --git a/gtk2_ardour/add_route_dialog.h b/gtk2_ardour/add_route_dialog.h
index 381bebee44..ec058dc130 100644
--- a/gtk2_ardour/add_route_dialog.h
+++ b/gtk2_ardour/add_route_dialog.h
@@ -67,7 +67,7 @@ public:
AudioBus,
MidiBus,
VCAMaster,
- ListenBus,
+ FoldbackBus,
};
TypeWanted type_wanted();
diff --git a/gtk2_ardour/ardour_ui.cc b/gtk2_ardour/ardour_ui.cc
index 049d26b069..0523f9a8d1 100644
--- a/gtk2_ardour/ardour_ui.cc
+++ b/gtk2_ardour/ardour_ui.cc
@@ -2123,17 +2123,17 @@ ARDOUR_UI::session_add_audio_route (
}
void
-ARDOUR_UI::session_add_listen_bus (uint32_t how_many, string const & name_template)
+ARDOUR_UI::session_add_foldback_bus (uint32_t how_many, string const & name_template)
{
RouteList routes;
assert (_session);
try {
- routes = _session->new_audio_route (2, 2, 0, how_many, name_template, PresentationInfo::ListenBus, -1);
+ routes = _session->new_audio_route (2, 2, 0, how_many, name_template, PresentationInfo::FoldbackBus, -1);
if (routes.size() != how_many) {
- error << string_compose (P_("could not create %1 new listen bus", "could not create %1 new listen busses", how_many), how_many)
+ error << string_compose (P_("could not create %1 new foldback bus", "could not create %1 new foldback busses", how_many), how_many)
<< endmsg;
}
}
@@ -4427,8 +4427,8 @@ ARDOUR_UI::add_route_dialog_response (int r)
case AddRouteDialog::VCAMaster:
_session->vca_manager().create_vca (count, name_template);
break;
- case AddRouteDialog::ListenBus:
- session_add_listen_bus (count, name_template);
+ case AddRouteDialog::FoldbackBus:
+ session_add_foldback_bus (count, name_template);
break;
}
}
diff --git a/gtk2_ardour/ardour_ui.h b/gtk2_ardour/ardour_ui.h
index 1f0e1145e9..d570dc79bb 100644
--- a/gtk2_ardour/ardour_ui.h
+++ b/gtk2_ardour/ardour_ui.h
@@ -316,7 +316,7 @@ public:
ARDOUR::PluginInfoPtr, ARDOUR::Plugin::PresetRecord*,
ARDOUR::PresentationInfo::order_t order);
- void session_add_listen_bus (uint32_t, std::string const &);
+ void session_add_foldback_bus (uint32_t, std::string const &);
void display_insufficient_ports_message ();
diff --git a/gtk2_ardour/processor_box.cc b/gtk2_ardour/processor_box.cc
index 21937bc607..550bdc2826 100644
--- a/gtk2_ardour/processor_box.cc
+++ b/gtk2_ardour/processor_box.cc
@@ -2034,7 +2034,7 @@ ProcessorBox::build_possible_aux_menu ()
return 0;
}
- if (_route->is_monitor () || _route->is_listenbus ()) {
+ if (_route->is_monitor () || _route->is_foldbackbus ()) {
return 0;
}
@@ -2047,7 +2047,7 @@ ProcessorBox::build_possible_aux_menu ()
/* don't allow sending to master or monitor or to self */
continue;
}
- if ((*r)->is_listenbus ()) {
+ if ((*r)->is_foldbackbus ()) {
continue;
}
if (_route->internal_send_for (*r)) {
@@ -2070,7 +2070,7 @@ ProcessorBox::build_possible_listener_menu ()
return 0;
}
- if (_route->is_monitor () || _route->is_listenbus ()) {
+ if (_route->is_monitor () || _route->is_foldbackbus ()) {
return 0;
}
@@ -2083,7 +2083,7 @@ ProcessorBox::build_possible_listener_menu ()
/* don't allow sending to master or monitor or to self */
continue;
}
- if (!(*r)->is_listenbus ()) {
+ if (!(*r)->is_foldbackbus ()) {
continue;
}
if (_route->internal_send_for (*r)) {
@@ -2106,7 +2106,7 @@ ProcessorBox::build_possible_remove_listener_menu ()
return 0;
}
- if (_route->is_monitor () || _route->is_listenbus ()) {
+ if (_route->is_monitor () || _route->is_foldbackbus ()) {
return 0;
}
@@ -2119,7 +2119,7 @@ ProcessorBox::build_possible_remove_listener_menu ()
/* don't allow sending to master or monitor or to self */
continue;
}
- if (!(*r)->is_listenbus ()) {
+ if (!(*r)->is_foldbackbus ()) {
continue;
}
if (!_route->internal_send_for (*r)) {
@@ -2192,8 +2192,8 @@ ProcessorBox::show_processor_menu (int arg)
}
}
- ActionManager::get_action (X_("ProcessorMenu"), "newinsert")->set_sensitive (!_route->is_monitor () && !_route->is_listenbus ());
- ActionManager::get_action (X_("ProcessorMenu"), "newsend")->set_sensitive (!_route->is_monitor () && !_route->is_listenbus ());
+ ActionManager::get_action (X_("ProcessorMenu"), "newinsert")->set_sensitive (!_route->is_monitor () && !_route->is_foldbackbus ());
+ ActionManager::get_action (X_("ProcessorMenu"), "newsend")->set_sensitive (!_route->is_monitor () && !_route->is_foldbackbus ());
ProcessorEntry* single_selection = 0;
if (processor_display.selection().size() == 1) {
@@ -2718,7 +2718,7 @@ ProcessorBox::choose_aux (boost::weak_ptr<Route> wr)
return;
}
- if (target->is_listenbus ()) {
+ if (target->is_foldbackbus ()) {
_route->add_foldback_send (target);
} else {
_session->add_internal_send (target, _placement, _route);
diff --git a/gtk2_ardour/add_route_dialog.cc b/gtk2_ardour/add_route_dialog.cc
index 57c9cc2719..d363211402 100644
--- a/gtk2_ardour/add_route_dialog.cc
+++ b/gtk2_ardour/add_route_dialog.cc
@@ -172,14 +172,14 @@ You may select:\n \
")
));
builtin_types.push_back (
- std::pair<string,string>(_("Listen Busses"), _(" \
-Use the settings, below, to create new Listen Busses.\n \
-Listen Busses are used as master outputs for monitor channels which are fed by\n \
+ std::pair<string,string>(_("Foldback Busses"), _(" \
+Use the settings, below, to create new Foldback Busses.\n \
+Foldback Busses are used as master outputs for monitor channels which are fed by\n \
hidden monitor sends.\n \
\n\n \
You may select:\n \
* The number of Listen Busses to add.\n \
* A name for the new Listen Busses.\n \
")
));
}
@@ -580,8 +580,8 @@ AddRouteDialog::type_wanted()
return AudioTrack;
} else if (str == _("VCA Masters")) {
return VCAMaster;
- } else if (str == _("Listen Busses")) {
- return ListenBus;
+ } else if (str == _("Foldback Busses")) {
+ return FoldbackBus;
} else {
assert (0);
return AudioTrack;
@@ -609,8 +609,8 @@ AddRouteDialog::maybe_update_name_template_entry ()
case MidiBus:
name_template_entry.set_text (_("Bus"));
break;
- case ListenBus:
- name_template_entry.set_text (_("Listener"));
+ case FoldbackBus:
+ name_template_entry.set_text (_("Foldback"));
break;
case VCAMaster:
name_template_entry.set_text (VCA::default_name_template());
@@ -757,7 +757,7 @@ AddRouteDialog::track_type_chosen ()
insert_at_combo.set_sensitive (true);
break;
- case ListenBus:
+ case FoldbackBus:
configuration_label.set_sensitive (false);
channel_combo.set_sensitive (false);
@@ -878,7 +878,7 @@ AddRouteDialog::channels ()
ret.set (DataType::MIDI, 1);
break;
- case ListenBus:
+ case FoldbackBus:
ret.set (DataType::AUDIO, 2);
ret.set (DataType::MIDI, 0);
break;
@@ -172,14 +172,14 @@ You may select:\n \
\n\n \
You may select:\n \
-* The number of Listen Busses to add.\n \
-* A name for the new Listen Busses.\n \
+* The number of Foldback Busses to add.\n \
+* A name for the new Foldback Busses.\n \
")
));